ant <- read.csv("ANTreg.csv", sep=";")
ant.1 <- ant[ant$TRACK == "ANT1", ]
ant.2 <- ant[ant$TRACK == "ANT2", ]
ant.3 <- ant[ant$TRACK == "ANT3", ]

med <- read.csv("MEDreg.csv", sep=";")
head(med)
med.1 <- med[med$TRACK == "MED1", ]
med.2 <- med[med$TRACK == "MED2", ]
med.3 <- med[med$TRACK == "MED3", ]


#### Spearman correlations ####

install.packages("car")
library(car)

## Antarctica

## Track 1
scatterplot(S~D, data=ant.1)
scatterplot(S~log(D+1), data=ant.1)
cor.test(~S+log(D+1), data = ant.1, method="spearman")

scatterplot(expH~D, data=ant.1)
scatterplot(expH~log(D+1), data=ant.1)
cor.test(~expH+log(D+1), data = ant.1, method="spearman")

## Track 2
scatterplot(S~D, data=ant.2)
scatterplot(S~log(D+1), data=ant.2)
cor.test(~S+log(D+1), data = ant.2, method="spearman")

scatterplot(expH~D, data=ant.2)
scatterplot(expH~log(D+1), data=ant.2)
cor.test(~expH+log(D+1), data = ant.2, method="spearman")

## Track 3

scatterplot(S~D, data=ant.3)
scatterplot(S~log(D+1), data=ant.3)
cor.test(~S+log(D+1), data = ant.3, method="spearman")

scatterplot(expH~D, data=ant.3)
scatterplot(expH~log(D+1), data=ant.3)
cor.test(~expH+log(D+1), data = ant.3, method="spearman")

## Mediterranean

## Track 1
scatterplot(S~D, data=med.1)
scatterplot(S~log(D+1), data=med.1)
cor.test(~S+log(D+1), data = med.1, method="spearman")

scatterplot(expH~D, data=med.1)
scatterplot(expH~log(D+1), data=med.1)
cor.test(~expH+log(D+1), data = med.1, method="spearman")

## Track 2
scatterplot(S~D, data=med.2)
scatterplot(S~log(D+1), data=med.2)
cor.test(~S+log(D+1), data = med.2, method="spearman")

scatterplot(expH~D, data=med.2)
scatterplot(expH~log(D+1), data=med.2)
cor.test(~expH+log(D+1), data = med.2, method="spearman")

## Track 3

scatterplot(S~D, data=med.3)
scatterplot(S~log(D+1), data=med.3)
cor.test(~S+log(D+1), data = med.3, method="spearman")

scatterplot(expH~D, data=med.3)
scatterplot(expH~log(D+1), data=med.3)
cor.test(~expH+log(D+1), data = med.3, method="spearman")

#### Linear regression models ####

#### ANTARCTICA 

##### Size vs species richness and diversity

### linear models for S versus gorgonian size
lmsize.ant.t <- lm(S~size, data=ant)
summary(lmsize.ant.t)



### linear models for expH versus gorgonian size
lmH.ant.t <- lm(expH~size, data=ant)
summary(lmH.ant.t)

##### Density vs species richness and diversity

###  linear models for  S vs density
mod.ant.t <- lm(S~log(D+1), data=ant)
summary(mod.ant.t)
par(mfrow = c(2, 2))
plot(mod.ant.t)

library(lmtest)
dwtest(mod.ant.t)

mod.ant.1 <- lm(S~log(D+1), data=ant.1)
summary(mod.ant.1)

mod.ant.2 <- lm(S~log(D+1), data=ant.2)
summary(mod.ant.2)

mod.ant.3 <- lm(S~log(D+1), data=ant.3)
summary(mod.ant.3)


plot(ant$S~ant$D, type="n", xlab= "gorgonian density (col./m^2)", ylab= "species richness (S)",
     main = "Antarctida")
points(ant.1$S~ant.1$D, pch=16, col="darkblue")
curve(2.8975*log(x+1)+10.9741, add=TRUE, col="darkblue", lty=2, lwd=1.5)
points(ant.2$S~ant.2$D, pch=16, col="orange")
curve(3.1811*log(x+1)+7.0999, add=TRUE, col="orange", lty=2, lwd=1.5)
points(ant.3$S~ant.3$D, pch=16, col="maroon1")
curve(7.6211*log(x+1)+2.5090, add=TRUE, col="maroon1", lty=2, lwd=1.5)

curve(4.5817*log(x+1)+7.5092, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("ANT1", "ANT2", "ANT3", "All transects"),
       col = c("darkblue", "orange", "maroon1", 1),  lty=c(2,2,2,1), lwd=1.5)



###  linear models for expH  vs density
mod.antH.t <- lm(expH~log(D+1), data=ant)
summary(mod.antH.t)
plot(mod.antH.t)

library(lmtest)

dwtest(mod.antH.t)

mod.antH.1 <- lm(expH~log(D+1), data=ant.1)
summary(mod.antH.1)

mod.antH.2 <- lm(expH~log(D+1), data=ant.2)
summary(mod.antH.2)

mod.antH.3 <- lm(expH~log(D+1), data=ant.3)
summary(mod.antH.3)

plot(ant$expH~ant$D, type="n", xlab= "gorgonian density (col./m^2)", ylab= "diversity (expH)")
points(ant.1$expH~ant.1$D, pch=16, col="darkblue")
curve(2.5008*log(x+1)+6.8361, add=TRUE, col="darkblue", lty=2, lwd=1.5)
points(ant.2$expH~ant.2$D, pch=16, col="orange")
curve(3.2817*log(x+1)+3.224, add=TRUE, col="orange", lty=2, lwd=1.5)
points(ant.3$expH~ant.3$D, pch=16, col="maroon1")
curve(5.2420*log(x+1)+2.0911, add=TRUE, col="maroon1", lty=2, lwd=1.5)

curve(3.6013*log(x+1)+4.5568, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("ANT1", "ANT2", "ANT3", "All transects"),
       col = c("darkblue", "orange", "maroon1", 1),  lty=c(2,2,2,1), lwd=1.5)

#### MEDITERRANEAN 

##### Size vs species richness and diversity

### linear models for S versus gorgonian size
lmsize.med.t <- lm(S~size, data=med)
summary(lmsize.med.t)



### linear models for expH versus gorgonian size
lmH.med.t <- lm(expH~size, data=med)
summary(lmH.med.t)

##### Density vs species richness and diversity

###  linear models for S vs density
mod.med.t <- lm(S~log(D+1), data=med)
summary(mod.med.t)

mod.med.1 <- lm(S~log(D+1), data=med.1)
summary(mod.med.1)

mod.med.2 <- lm(S~log(D+1), data=med.2)
summary(mod.med.2)

mod.med.3 <- lm(S~log(D+1), data=med.3)
summary(mod.med.3)

plot(med$S~med$D, type="n", xlab= "gorgonian density (col./m^2)", ylab= "species richness (S)",
     main = "Mediterranean Sea")
points(med.1$S~med.1$D, pch=16, col="darkblue")
curve(2.889*log(x+1)+7.263, add=TRUE, col="darkblue", lty=2, lwd=1.5)
points(med.2$S~med.2$D, pch=16, col="orange")
curve(2.3138*log(x+1)+1.8973, add=TRUE, col="orange", lty=2, lwd=1.5)
points(med.3$S~med.3$D, pch=16, col="maroon1")
curve(1.7661*log(x+1)+4.2254, add=TRUE, col="maroon1", lty=2, lwd=1.5)

curve(3.0448*log(x+1)+3.2353, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("MED1", "MED2", "MED3", "All transects"),
       col = c("darkblue", "orange", "maroon1", 1),  lty=c(2,2,2,1), lwd=1.5)

###  linear models for expH vs density
mod.medH.t <- lm(expH~log(D+1), data=med)
summary(mod.medH.t)

mod.medH.1 <- lm(expH~log(D+1), data=med.1)
summary(mod.medH.1)

mod.medH.2 <- lm(expH~log(D+1), data=med.2)
summary(mod.medH.2)

mod.medH.3 <- lm(expH~log(D+1), data=med.3)
summary(mod.medH.3)

plot(med$expH~med$D, type="n", xlab= "gorgonian density (col./m^2)", ylab= "diversity (expH)")
points(med.1$expH~med.1$D, pch=16, col="darkblue")
curve(2.0183*log(x+1)+5.2629, add=TRUE, col="darkblue", lty=2, lwd=1.5)
points(med.2$expH~med.2$D, pch=16, col="orange")
curve(1.9118*log(x+1)+1.6792, add=TRUE, col="orange", lty=2, lwd=1.5)
points(med.3$expH~med.3$D, pch=16, col="maroon1")
curve(0.8789*log(x+1)+3.7269, add=TRUE, col="maroon1", lty=2, lwd=1.5)

curve(1.9945*log(x+1)+2.7974, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("MED1", "MED2", "MED3", "All transects"),
       col = c("darkblue", "orange", "maroon1", 1),  lty=c(2,2,2,1), lwd=1.5)


###graphic 2 x 2 
par(mfrow = c(2, 2))

plot(med$S~med$D, type="n", ylab= "Species richness (S)", xlab= "",
     main = "Mediterranean Sea")
points(med.1$S~med.1$D, pch=16, col="deeppink4")
curve(2.889*log(x+1)+7.263, add=TRUE, col="deeppink4", lty=2, lwd=1.5)
points(med.2$S~med.2$D, pch=16, col="chocolate1")
curve(2.3138*log(x+1)+1.8973, add=TRUE, col="chocolate1", lty=2, lwd=1.5)
points(med.3$S~med.3$D, pch=16, col="chartreuse3")
curve(1.7661*log(x+1)+4.2254, add=TRUE, col="chartreuse3", lty=2, lwd=1.5)

curve(3.0448*log(x+1)+3.2353, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("MED1", "MED2", "MED3", "All transects"),
       col = c("deeppink4", "chocolate1", "chartreuse3", 1), cex = 0.8, lty=c(2,2,2,1), lwd=1.5)

plot(ant$S~ant$D, type="n", ylab= "Species richness (S)", xlab= "",
     main = "Weddell Sea")
points(ant.1$S~ant.1$D, pch=16, col="deeppink4")
curve(2.8975*log(x+1)+10.9741, add=TRUE, col="deeppink4", lty=2, lwd=1.5)
points(ant.2$S~ant.2$D, pch=16, col="chocolate1")
curve(3.1811*log(x+1)+7.0999, add=TRUE, col="chocolate1", lty=2, lwd=1.5)
points(ant.3$S~ant.3$D, pch=16, col="chartreuse3")
curve(7.6211*log(x+1)+2.5090, add=TRUE, col="chartreuse3", lty=2, lwd=1.5)

curve(4.5817*log(x+1)+7.5092, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("ANT1", "ANT2", "ANT3", "All transects"),
       col = c("deeppink4", "chocolate1", "chartreuse3", 1),  cex = 0.8, lty=c(2,2,2,1), lwd=1.5)

plot(med$expH~med$D, type="n", xlab= "Gorgonian density (col./m^2)", ylab= "Diversity (expH)")
points(med.1$expH~med.1$D, pch=16, col="deeppink4")
curve(2.0183*log(x+1)+5.2629, add=TRUE, col="deeppink4", lty=2, lwd=1.5)
points(med.2$expH~med.2$D, pch=16, col="chocolate1")
curve(1.9118*log(x+1)+1.6792, add=TRUE, col="chocolate1", lty=2, lwd=1.5)
points(med.3$expH~med.3$D, pch=16, col="chartreuse3")
curve(0.8789*log(x+1)+3.7269, add=TRUE, col="chartreuse3", lty=2, lwd=1.5)

curve(1.9945*log(x+1)+2.7974, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("MED1", "MED2", "MED3", "All transects"),
       col = c("deeppink4", "chocolate1", "chartreuse3", 1),  cex = 0.8, lty=c(2,2,2,1), lwd=1.5)

plot(ant$expH~ant$D, type="n", xlab= "Gorgonian density (col./m^2)", ylab= "Diversity (expH)")
points(ant.1$expH~ant.1$D, pch=16, col="deeppink4")
curve(2.5008*log(x+1)+6.8361, add=TRUE, col="deeppink4", lty=2, lwd=1.5)
points(ant.2$expH~ant.2$D, pch=16, col="chocolate1")
curve(3.2817*log(x+1)+3.224, add=TRUE, col="chocolate1", lty=2, lwd=1.5)
points(ant.3$expH~ant.3$D, pch=16, col="chartreuse3")
curve(5.2420*log(x+1)+2.0911, add=TRUE, col="chartreuse3", lty=2, lwd=1.5)

curve(3.6013*log(x+1)+4.5568, add=TRUE, col=1, lwd=2)
legend("bottomright", bty="n", legend = c("ANT1", "ANT2", "ANT3", "All transects"),
       col = c("deeppink4", "chocolate1", "chartreuse3", 1),  cex = 0.8, lty=c(2,2,2,1), lwd=1.5)

##### PCoA ####

###  ANTARCTICA
par(mfrow = c(1, 1))
antPCo <- read.csv("MDS-ANT.csv", sep=";")
antPCo<-antPCo[,1:111]
head(antPCo)


ant.D <-vegdist(sqrt(antPCo[,4:111]), "bray")
grp<- antPCo[,3]

ant.PCoA1 <-cmdscale(ant.D)
summary(ant.PCoA1)
print(ant.PCoA1)

ant.PCoA <-as.data.frame(ant.PCoA1)


ant.PCoA$Density<-antPCo$level
ant.PCoA$Density<- as.character(ant.PCoA$Density)
names(ant.PCoA)[1:2] <- c('PCoA1', 'PCoA2')
gr.Palette<-c("deeppink4", "chocolate1", "chartreuse3") 

library(ggplot2)
g.ant <- ggplot(ant.PCoA, aes(x = PCoA1, y = PCoA2, colour = Density))
     g.ant + geom_point(size=2) +
       scale_colour_manual(values = gr.Palette) + 
       theme_bw() +
       ggtitle("Weddell Sea") + 
       stat_ellipse(level = 0.6, linetype=2)+ 
       theme(plot.title=element_text( face='bold', size =16)) + 
       theme(axis.text = element_text( size=12)) +
       theme(axis.title = element_text( size=14, face = 2)) +
       theme(legend.text = element_text(size = 12)) +
       theme(legend.title = element_text(size = 12, face = 2))+
       theme(
         legend.position = c(.05, .05),
         legend.justification = c("left", "bottom"),
         legend.box.just = "right",
         legend.margin = margin(6, 6, 6, 6)
       )

####  PERMANOVA 
     
library(ape)
library(vegan)
library(devtools)
install_github("pmartinezarbizu/pairwiseAdonis/pairwiseAdonis")
library(pairwiseAdonis)
citation("pairwiseAdonis")
     
     
antPerma<-adonis(sqrt(antPCo[,4:111])~level, data = antPCo)
summary(antPerma)
print(antPerma)
     
pairwise.adonis(sqrt(antPCo[,4:111]), antPCo$level)
     

     
####  Mediterranean

medPCo <- read.csv("MDS-MED.csv", sep=";")
head(medPCo)
medPCo<-medPCo[,1:206]
head(medPCo)


med.D <-vegdist(sqrt(medPCo[,4:206]), "bray")
grpM<- medPCo[,3]

med.PCoA1 <-cmdscale(med.D)
summary(med.PCoA1)
print(med.PCoA1)

med.PCoA <-as.data.frame(med.PCoA1)


med.PCoA$Density<-medPCo$level
med.PCoA$Density<- as.character(med.PCoA$Density)
names(med.PCoA)[1:2] <- c('PCoA1', 'PCoA2')
gr.Palette<-c("deeppink4", "chocolate1", "chartreuse3") 

library(ggplot2)
g.med <- ggplot(med.PCoA, aes(x = PCoA1, y = PCoA2, colour = Density))
g.med + geom_point(size=2) +
  scale_colour_manual(values = gr.Palette) + theme_bw()+
  ggtitle("Mediterranean Sea") + 
  stat_ellipse(level = 0.6, linetype=2) + 
  theme(plot.title=element_text( face='bold', size =16)) + 
  theme(axis.text = element_text( size=12)) +
  theme(axis.title = element_text( size=14, face = 2)) +
  theme(legend.text = element_text(size = 12)) +
  theme(legend.title = element_text(size = 12, face = 2)) +
theme(
  legend.position = c(.95, .05),
  legend.justification = c("right", "bottom"),
  legend.box.just = "right",
  legend.margin = margin(6, 6, 6, 6)
)

#### PERMANOVA 

medPerma<-adonis(sqrt(medPCo[,4:206])~medPCo[,3])
print(medPerma)

pairwise.adonis(sqrt(medPCo[,4:206]), medPCo$level)
